# **nenupy**

[![nenupy](https://img.shields.io/pypi/v/nenupy.svg)](
    https://pypi.python.org/pypi/nenupy)
<!--[![PyPI download month](https://img.shields.io/pypi/dm/nenupy.svg)](
    https://pypi.python.org/pypi/nenupy/) -->
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/nenupy.svg)](
    https://pypi.python.org/pypi/nenupy/)
<!--[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3667816.svg)](https://doi.org/10.5281/zenodo.3667816) v0.5.7 -->
[![DOI](https://zenodo.org/badge/150578164.svg)](https://zenodo.org/badge/latestdoi/150578164)
[![Documentation Status](https://img.shields.io/readthedocs/nenupy/latest.svg?logo=read%20the%20docs&logoColor=white&label=Docs&version=stable)](https://nenupy.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/AlanLoh/nenupy/branch/master/graph/badge.svg)](https://codecov.io/gh/AlanLoh/nenupy)
![Python package](https://github.com/AlanLoh/nenupy/workflows/Python%20package/badge.svg)
[![astropy](http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat)](http://www.astropy.org/)

<!-- ![Alt text](./Logo-NenuFAR-noir.svg) -->
<p align="center">
<img src="./Logo-NenuFAR-noir.svg" width="20%">
</p>

Python3 package for the low-frequency radio telescope NenuFAR.

See [documentation](https://nenupy.readthedocs.io/en/latest/)